@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 $|++;
 
-our $VERSION = '1.05';
+our $VERSION = '1.07';
 
 # Regex to match balanced params. Reproduced from Regexp::Common to avoid
 # adding a non-core dependency.
@@ -92,7 +92,8 @@ sub prefilter {
     $code =~ s{
         ^\s*\K                    # okay to have leading whitespace (preserve)
         $keyword             \s+  # the "func/method" keyword
-        (?<subname> $subname) \s* # the function name or class name (needs ::)
+        (?<subname> $subname)     # the function name or class name (needs ::)
+        (?!\w|\s*=>) \s*          # check to make sure this isn't a sub call with params
         @{[ $self->clauses ]}     # any clauses defined (ie, a parameter list)
         (?<brace> .*?)            # anything else (ie, comments) including brace
         $
@@ -145,7 +146,7 @@ Perl::Tidy::Sweetened::Keyword::Block - Perl::Tidy::Sweetened filter plugin to d
 
 =head1 VERSION
 
-version 1.05
+version 1.07
 
 =head1 SYNOPSIS
 
@@ -214,22 +215,43 @@ is significant.
 
 =back
 
-=head1 THANKS
+=head1 AUTHOR
 
-See L<Perl::Tidy::Sweetened>
+Mark Grimes E<lt>mgrimes@cpan.orgE<gt>
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Kent Fredric (@kentnl)
+
+=item *
+
+Gregoy Oschwald (@oschwal)
+
+=item *
+
+Curtis Brandt (@aggrolite)
+
+=back
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/mvgrimes/Perl-Tidy-Sweetened>.
 
 =head1 BUGS
 
-Please report any bugs or suggestions at
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Perl-Tidy-Sweetened>
+Please report any bugs or feature requests on the bugtracker website L<http://github.com/mvgrimes/perl-tidy-sweetened/issues>
 
-=head1 AUTHOR
-
-Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
+This software is copyright (c) 2016 by Mark Grimes E<lt>mgrimes@cpan.orgE<gt>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
